@@ -1,6 +1,6 @@
 package XAS::Apps::Test::Echo::Client;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Try::Tiny;
 use XAS::Lib::Net::Client;
@@ -8,7 +8,7 @@ use XAS::Lib::Net::Client;
 use XAS::Class
   version   => $VERSION,
   base      => 'XAS::Lib::App',
-  accessors => 'handle'
+  accessors => 'handle port host send'
 ;
 
 # ----------------------------------------------------------------------
@@ -31,12 +31,12 @@ sub do_echo {
     my $message;
 
     $self->handle->connect();
-    $self->handle->put($self->send);
+    $self->handle->puts($self->send);
 
-    $message = $self->handle->get();
+    $message = $self->handle->gets();
     $self->handle->disconnect();
 
-    $self->log('info', sprintf("echo = %s", $message));
+    $self->log->info(sprintf("echo = %s", $message));
 
 }
 
@@ -45,11 +45,26 @@ sub main {
 
     $self->setup();
 
-    $self->log('debug', 'Starting main section');
+    $self->log->debug('Starting main section');
 
     $self->do_echo();
 
-    $self->log('debug', 'Ending main section');
+    $self->log->debug('Ending main section');
+
+}
+
+sub options {
+    my $self = shift;
+
+    $self->{send} = '';
+    $self->{port} = '9505';
+    $self->{host} = 'localhost';
+
+    return {
+        'port=s' => \$self->{port},
+        'host=s' => \$self->{host},
+        'send=s' => \$self->{send},
+    };
 
 }
 
@@ -70,12 +85,7 @@ XAS::Apps::Test::Echo::Client - This module will send data to the echo server
  use XAS::Apps::Test::Echo::Client;
 
  my $app = XAS::Apps::Test::Echo::Client->new(;
-    -throws  => 'pg_remove_data',
-    -options => [
-        {'port=s', '9505'},
-        {'host=s', 'localhost'},
-        {'send=s', ''}
-    ]
+    -throws  => 'echo-client',
  );
 
  exit $app->run();
@@ -87,28 +97,24 @@ This module will send a message to the echo server. This message should be
 
 =head1 CONFIGURATION
 
-The following parameters are used to configure the module.
+There is no additional configuration.
 
-=head2 -options
+=head1 OPTIONS
 
-Defines the command line options for this module. 
+This module provides these additonal cli options.
 
-=over 4
+=head2 --host
 
-=item B<'host=s'>
+The host the echo server resides on. Defaults to 'localhost'.
 
-The host the echo server resides on.
+=head2 --port
 
-=item B<'port=s'>
+The port it is listening on. Defaults to '9505'.
 
-The port it is listening on.
-
-=item B<'send=s'>
+=head2 --send
 
 The text to be "echoed" back.
 
-=back
-
 =head1 SEE ALSO
 
 =over 4
@@ -127,8 +133,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2012 by Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
