@@ -52,7 +52,7 @@ use Badger::Class
       # logging
 
       LOG_LEVELS   => qr/info|warn|error|fatal|debug|trace/,
-      LOG_TYPES    => qr/console|file|logstash|syslog/,
+      LOG_TYPES    => qr/console|file|json|syslog/,
       LOG_FACILITY => qr/auth|authpriv|cron|daemon|ftp|local[0-7]|lpr|mail|news|user|uucp/,
 
       # alerts
@@ -112,7 +112,7 @@ XAS::Constants - A Perl extension for the XAS environment
 =head1 DESCRIPTION
 
 This module provides various constants for the XAS enviromnet. It inherits from
-L<Badger::Constants|http://badgerpower.com/docs/Badger/Constants.html> and also provides these additional
+L<Badger::Constants|https://metacpan.org/pod/Badger::Constants> and also provides these additional
 constants.
 
 =head2 EXPORT
@@ -148,10 +148,8 @@ Kevin Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
