@@ -5,17 +5,18 @@ our $VERSION = '0.01';
 use XAS::Lib::Stomp::Parser;
 
 use XAS::Class
-  debug   => 0,
-  version => $VERSION,
-  base    => 'XAS::Base',
-  accessors => 'filter',
-  vars => {
-    PARAMS => {
-      -target  => { optional => 1, default => '1.0', regex => qr/(1\.0|1\.1|1\.2)/ },
-    }
-  }
+  debug     => 0,
+  version   => $VERSION,
+  base      => 'XAS::Base',
+  accessors => 'filter eol',
+  constants => 'CRLF',
+  constant => {
+    LF  => "\n",
+  },
 ;
 
+#use Data::Hexdumper;
+
 # ---------------------------------------------------------------------
 # Public methods
 # ---------------------------------------------------------------------
@@ -66,6 +67,7 @@ sub put {
 
         my $buffer = $frame->as_string;
 
+#        $self->log->debug(hexdump($buffer));
         push(@ret, $buffer);
 
     }
@@ -83,10 +85,8 @@ sub init {
 
     my $self = $class->SUPER::init(@_);
 
-    $self->{filter} = XAS::Lib::Stomp::Parser->new(
-        -target => $self->target,
-        -xdebug => $self->xdebug,
-    );
+    $self->{eol} = ($self->env->mqlevel > 1.1) ? CRLF : LF;
+    $self->{filter} = XAS::Lib::Stomp::Parser->new();
 
     return $self;
 
@@ -108,7 +108,7 @@ XAS::Lib::Stomp::POE::Filter - An I/O filter for the POE Environment
 
   POE::Component::Server::TCP->new(
       ...
-      Filter => XAS::Lib::Stomp::POE::Filter->new(-target => '1.0'),
+      Filter => XAS::Lib::Stomp::POE::Filter->new(),
       ...
   );
 
@@ -116,28 +116,54 @@ XAS::Lib::Stomp::POE::Filter - An I/O filter for the POE Environment
 
   POE::Component::Client::TCP->new(
       ...
-      Filter => XAS::Lib::Stomp::POE::Filter->new(-target => '1.0'),
+      Filter => XAS::Lib::Stomp::POE::Filter->new(),
       ...
   );
 
 =head1 DESCRIPTION
 
 This module is a filter for the POE environment. It will translate the input
-buffer into XAS::Lib::Stomp::Frame objects and serialize the output buffer 
-from said object. 
+buffer into L<XAS::Lib::Stomp::Frame|XAS::Lib::Stomp::Frame> objects and 
+serialize the output buffer from said object. 
 
 =head1 METHODS
 
 =head2 new
 
-This method initializes the module. It takes these parameters:
+This method initializes the module.
+
+=head2 get_one_start($buffers)
+
+This method parses one frame for a buffer and stores it in an internal frames 
+buffer.
 
 =over 4
 
-=item B<-target>
+=item B<$buffers>
 
-Specify a STOMP protocol version number. It currently supports 1.0,
-1.1 and 1.2, defaulting to 1.0.
+A reference to a buffer.
+
+=back
+
+=head2 get_one
+
+This method returns one frame from the internal buffer.
+
+=head2 get_pending
+
+This method returns the number of pending frames.
+
+=head2 put($buffers)
+
+This method pulls frames out of the buffer, stringifies them and places them
+into a internal array. When done it returns that array.
+
+=over 4
+
+=item B<$buffers>
+
+A reference to a buffer of L<XAS::Lib::Stomp::Frame|XAS::Lib::Stomp::Frame> 
+frames.
 
 =back
 
@@ -149,7 +175,7 @@ Specify a STOMP protocol version number. It currently supports 1.0,
 
 =back
 
-See the documentation for POE::Filter for usage.
+See the documentation for L<POE::Filter|https://metacpan.org/pod/POE::Filter> for usage.
 
 For more information on the STOMP protocol, please refer to: L<http://stomp.github.io/> .
 
@@ -161,10 +187,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
