@@ -1,6 +1,6 @@
 package XAS::Utils;
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 use DateTime;
 use Try::Tiny;
@@ -17,38 +17,28 @@ use XAS::Class
   base       => 'Badger::Utils XAS::Base',
   constants  => 'HASH ARRAY',
   filesystem => 'Dir File',
-  constant => {
-    ERRMSG => 'invalid parameters passed from %s at line %s', 
-  },
   exports => {
     all => 'db2dt dt2db trim ltrim rtrim daemonize hash_walk  
             load_module bool init_module load_module compress exitcode 
             kill_proc spawn _do_fork glob2regex dir_walk
             env_store env_restore env_create env_parse env_dump
-            left right mid instr',
+            left right mid instr is_truthy is_falsey run_cmd',
     any => 'db2dt dt2db trim ltrim rtrim daemonize hash_walk  
             load_module bool init_module load_module compress exitcode 
             kill_proc spawn _do_fork glob2regex dir_walk
             env_store env_restore env_create env_parse env_dump
-            left right mid instr',
+            left right mid instr is_truthy is_falsey run_cmd',
     tags => {
       dates   => 'db2dt dt2db',
       env     => 'env_store env_restore env_create env_parse env_dump',
       modules => 'init_module load_module',
       strings => 'trim ltrim rtrim compress left right mid instr',
       process => 'daemonize spawn kill_proc exitcode _do_fork',
+      boolean => 'is_truthy is_falsey bool',
     }
   }
 ;
 
-Params::Validate::validation_options(
-    on_fail => sub {
-        my $params = shift;
-        my $class  = __PACKAGE__;
-        XAS::Base::validation_exception($params, $class);
-    }
-);
-
 #use Data::Dumper;
 
 # ----------------------------------------------------------------------
@@ -57,16 +47,15 @@ Params::Validate::validation_options(
 
 # recursively walk a HOH
 sub hash_walk {
-
-    my %p = validate(@_, {
+    my $p = XAS::Base->validate_params(\@_, {
         -hash     => { type => HASHREF }, 
         -keys     => { type => ARRAYREF }, 
         -callback => { type => CODEREF },
     });
 
-    my $hash     = $p{'-hash'};
-    my $key_list = $p{'-keys'};
-    my $callback = $p{'-callback'};
+    my $hash     = $p->{'hash'};
+    my $key_list = $p->{'keys'};
+    my $callback = $p->{'callback'};
 
     while (my ($k, $v) = each %$hash) {
 
@@ -98,27 +87,19 @@ sub hash_walk {
 
 # recursively walk a directory structure
 sub dir_walk {
-    my %p = validate_with(
-        params => \@_,
-        spec => {
-            -directory => { isa  => 'Badger::Filesystem::Directory' },
-            -callback  => { type => CODEREF },
-            -filter    => { optional => 1, default => qr/.*/, callbacks => {
-                'must be a compiled regex' => sub {
-                    return (ref shift() eq 'Regexp') ? 1 : 0;
-                }
-            }},
-        },
-        on_fail => sub {
-            my $param = shift;
-            my $class = (caller(1))[3];
-            XAS::Base::validation_exception($param, $class);
-        }
-    );
+    my $p = XAS::Base->validate_params(\@_, {
+        -directory => { isa  => 'Badger::Filesystem::Directory' },
+        -callback  => { type => CODEREF },
+        -filter    => { optional => 1, default => qr/.*/, callbacks => {
+            'must be a compiled regex' => sub {
+                return (ref shift() eq 'Regexp') ? 1 : 0;
+            }
+        }},
+    });
 
-    my $folder   = $p{'-directory'};
-    my $filter   = $p{'-filter'};
-    my $callback = $p{'-callback'};
+    my $folder   = $p->{'directory'};
+    my $filter   = $p->{'filter'};
+    my $callback = $p->{'callback'};
 
     my @files = grep ( $_->path =~ /$filter/, $folder->files() );
     my @folders = $folder->dirs;
@@ -139,7 +120,7 @@ sub dir_walk {
 
 # Perl trim function to remove whitespace from the start and end of the string
 sub trim {
-    my $string = shift;
+    my ($string) = XAS::Base->validate_params(\@_, [1]);
 
     $string =~ s/^\s+//;
     $string =~ s/\s+$//;
@@ -150,7 +131,7 @@ sub trim {
 
 # Left trim function to remove leading whitespace
 sub ltrim {
-    my $string = shift;
+    my ($string) = XAS::Base->validate_params(\@_, [1]);
 
     $string =~ s/^\s+//;
 
@@ -160,7 +141,7 @@ sub ltrim {
 
 # Right trim function to remove trailing whitespace
 sub rtrim {
-    my $string = shift;
+    my ($string) = XAS::Base->validate_params(\@_, [1]);
 
     $string =~ s/\s+$//;
 
@@ -170,7 +151,7 @@ sub rtrim {
 
 # replace multiple whitspace with a single space
 sub compress {
-    my $string = shift;
+    my ($string) = XAS::Base->validate_params(\@_, [1]);
 
     $string =~ s/\s+/ /gms;
 
@@ -180,8 +161,7 @@ sub compress {
 
 # emulate Basics string function left()
 sub left {
-    my $string = shift;
-    my $offset = shift;
+    my ($string, $offset) = XAS::Base->validate_params(\@_, [1,1]);
 
     return substr($string, 0, $offset);
 
@@ -189,8 +169,7 @@ sub left {
 
 # emulate Basics string function right()
 sub right {
-    my $string = shift;
-    my $offset = shift;
+    my ($string, $offset) = XAS::Base->validate_params(\@_, [1,1]);
 
     return substr($string, -($offset));
 
@@ -198,9 +177,7 @@ sub right {
 
 # emulate Basics string function mid()
 sub mid {
-    my $string = shift;
-    my $start  = shift;
-    my $length = shift;
+    my ($string, $start, $length) = XAS::Base->validate_params(\@_, [1,1,1]);
 
     return substr($string, $start - 1, $length);
 
@@ -208,9 +185,7 @@ sub mid {
 
 # emulate Basics string function instr()
 sub instr {
-    my $start   = shift;
-    my $string  = shift;
-    my $compare = shift;
+    my ($start, $string, $compare) = XAS::Base->validate_params(\@_, [1,1,1]);
 
     if ($start =~ /^[0-9\-]+/) {
 
@@ -228,17 +203,40 @@ sub instr {
 
 }
 
-sub bool {
-    my $item = shift;
+# Checks to see if the parameter is the string 't', 'true', 'yes', '0E0' 
+# or the number 1.
+#
+sub is_truthy {
+    my ($parm) = XAS::Base->validate_params(\@_, [1]);
 
-    my @truth = qw(yes true 1 0e0);
+    my @truth = qw(yes true t 1 0e0);
+
+    return scalar(grep {lc($parm) eq $_} @truth);
+
+}
+
+# Checks to see if the parameter is the string 'f', 'false', 'no' or 
+# the number 0.
+#
+sub is_falsey {
+    my ($parm) = XAS::Base->validate_params(\@_, [1]);
+
+    my @truth = qw(no false f 0);
+
+    return scalar(grep {lc($parm) eq $_} @truth);
+
+}
+
+sub bool {
+    my ($item) = XAS::Base->validate_params(\@_, [1]);
+
+    my @truth = qw(yes true 1 0e0 no false f 0);
     return grep {lc($item) eq $_} @truth;
 
 }
 
 sub spawn {
-
-    my %p = validate(@_, {
+    my $p = XAS::Base->validate_params(\@_, {
         -command => 1,
         -timeout => { optional => 1, default => 0 },
     });
@@ -268,12 +266,12 @@ sub spawn {
 
         try {
 
-            alarm( $p{'-timeout'} );
+            alarm( $p->{'timeout'} );
 
             while (<$kid>) {
 
                 chomp;
-                push @output, $_;
+                push(@output, $_);
 
             }
 
@@ -291,7 +289,7 @@ sub spawn {
 
                     unless (kill_proc(-signal => 'KILL', -pid => $pid)) {
 
-                        my $ex = Badger::Exception->new(
+                        my $ex = XAS::Exception->new(
                             type => 'xas.utils.spawn',
                             info => 'unable to kill ' . $pid
                         );
@@ -318,7 +316,7 @@ sub spawn {
         # kill -9 will kill it and all its descendents
 
         setpgrp(0, 0);
-        exec $p{'-command'};
+        exec $p->{'command'};
         exit;
 
     }
@@ -328,16 +326,15 @@ sub spawn {
 }
 
 sub kill_proc {
-
-    my %p = validate(@_, {
+    my $p = XAS::Base->validate_params(\@_, {
         -signal => 1,
         -pid    => 1,
     });
 
     my $time = 10;
     my $status = 0;
-    my $pid = $p{'-pid'};
-    my $signal = $p{'-signal'};
+    my $pid = $p->{'pid'};
+    my $signal = $p->{'signal'};
 
     kill($signal, $pid);
 
@@ -401,178 +398,111 @@ sub daemonize {
 }
 
 sub db2dt {
-    my ($p) = shift;
+    my ($p) = XAS::Base->validate_params(\@_, [
+        { regex => qr/\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}/ }
+    ]);
 
-    my $dt;
-    my $parser;
+    my $parser = DateTime::Format::Strptime->new(
+        pattern => '%Y-%m-%d %H:%M:%S',
+        time_zone => 'local',
+        on_error => sub {
+            my ($obj, $err) = @_;
+            my $ex = XAS::Exception->new(
+                type => 'xas.utils.db2dt',
+                info => $err
+            );
+            $ex->throw;
+        }
+    );
 
-    if ($p =~ m/\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}/) {
-
-        $parser = DateTime::Format::Strptime->new(
-            pattern => '%Y-%m-%d %H:%M:%S',
-            time_zone => 'local',
-            on_error => sub {
-                my ($obj, $err) = @_;
-	            my $ex = XAS::Exception->new(
-                    type => 'xas.utils.db2dt',
-                    info => $err
-                );
-                $ex->throw;
-            }
-        );
-
-        $dt = $parser->parse_datetime($p);
-
-    } else {
-
-        my ($package, $file, $line) = caller;
-        my $ex = XAS::Exception->new(
-            type => 'xas.utils.db2dt',
-            info => sprintf(ERRMSG, $package, $line)
-        );
-
-        $ex->throw;
-
-    }
-
-    return $dt;
+    return $parser->parse_datetime($p);
 
 }
 
 sub dt2db {
-    my ($p) = shift;
+    my ($dt) = XAS::Base->validate_params(\@_, [
+        { isa => 'DateTime' }
+    ]);
 
-    my $ft;
-    my $parser;
+    return $dt->strftime('%Y-%m-%d %H:%M:%S');
 
-    my $ref = ref($p);
+}
 
-    if ($ref && $p->isa('DateTime')) {
+sub run_cmd {
+    my ($command) = XAS::Base->validate_params(\@_, [1]);
 
-        $parser = DateTime::Format::Strptime->new(
-            pattern => '%Y-%m-%d %H:%M:%S',
-            time_zone => 'local',
-            on_error => sub {
-                my ($obj, $err) = @_;
-	            my $ex = XAS::Exception->new(
-                    type => 'xas.utils.dt2db',
-                    info => $err
-                );
-                $ex->throw;
-            }
-        );
+    my @output = `$command 2>&1`;
+    my ($rc, $sig) = exitcode();
 
-        $ft = $parser->format_datetime($p);
-
-    } else {
-
-        my ($package, $file, $line) = caller;
-        my $ex = XAS::Exception->new(
-            type => 'xas.utils.dt2db',
-            info => sprintf(ERRMSG, $package, $line)
-        );
-
-        $ex->throw;
-
-    }
-
-    return $ft;
+    return \@output, $rc, $sig;
 
 }
 
 sub init_module {
-    my ($module, $params) = validate_pos(@_, 
+    my ($module, $params) = XAS::Base->validate_params(@_, [ 
         1, 
-        {optional => 1, type => HASHREF}
-    );
+        { optional => 1, type => HASHREF, default => {} }
+    ]);
 
     my $obj;
     my @parts;
     my $filename;
 
-    $params = {} unless (defined($params));
+    @parts = split("::", $module);
+    $filename = File(@parts);
 
-    if ($module) {
+    try {
 
-        @parts = split("::", $module);
-        $filename = File(@parts);
+        require $filename . '.pm';
+        $module->import();
+        $obj = $module->new($params);
 
-        try {
+    } catch {
 
-            require $filename . '.pm';
-            $module->import();
-            $obj = $module->new($params);
-
-        } catch {
-
-            my $x = $_;
-            my $ex = Badger::Exception->new(
-                type => 'xas.utils.init_module',
-                info => $x
-            );
-
-            $ex->throw;
-
-        };
-
-    } else {
-
-        my $ex = Badger::Exception->new(
+        my $x = $_;
+        my $ex = XAS::Exception->new(
             type => 'xas.utils.init_module',
-            info => 'no module was defined'
+            info => $x
         );
 
         $ex->throw;
 
-    }
+    };
 
     return $obj;
 
 }
 
 sub load_module {
-    my $module = shift;
+    my ($module) = XAS::Base->validate_params(\@_, [1]);
 
     my @parts;
     my $filename;
 
-    if ($module) {
+    @parts = split("::", $module);
+    $filename = File(@parts);
 
-        @parts = split("::", $module);
-        $filename = File(@parts);
+    try {
 
-        try {
+        require $filename . '.pm';
+        $module->import();
 
-            require $filename . '.pm';
-            $module->import();
-
-        } catch {
-
-            my $x = $_;
-            my $ex = XAS::Exception->new(
-                type => 'xas.utils.load_module',
-                info => $x
-            );
-
-            $ex->throw;
-
-        };
-
-    } else {
+    } catch {
 
+        my $x = $_;
         my $ex = XAS::Exception->new(
             type => 'xas.utils.load_module',
-            info => 'no module was defined'
+            info => $x
         );
 
         $ex->throw;
 
-    }
+    };
 
 }
 
 sub glob2regex {
-    my $globstr = shift;
+    my ($globstr) = XAS::Base->validate_params(\@_, [1]);
 
     my %patmap = (
         '*' => '.*',
@@ -603,7 +533,7 @@ sub env_store {
 }
 
 sub env_restore {
-    my $env = shift;
+    my ($env) = XAS::Base->validate_params(\@_, [1]);
 
     while ((my $key, my $value) = each(%ENV)) {
 
@@ -620,7 +550,7 @@ sub env_restore {
 }
 
 sub env_create {
-    my $env = shift;
+    my ($env) = XAS::Base->validate_params(\@_, [1]);
 
     while ((my $key, my $value) = each(%{$env})) {
 
@@ -631,7 +561,7 @@ sub env_create {
 }
 
 sub env_parse {
-    my $env = shift;
+    my ($env) = XAS::Base->validate_params(\@_, [1]);
 
     my ($key, $value, %env);
     my @envs = split(';;', $env);
@@ -766,6 +696,15 @@ Decodes Perls version of the exit code from a cli process. Returns two items.
      my @output = spawn(-command => "ls -l");
      my ($rc, $sig) = exitcode();
 
+=head2 run_cmd($command)
+
+Run a command and capture the output and exit code, stderr is merged
+with stdout.
+
+ Example:
+ 
+     my (@output, $rc) = run_cmd("ls -l");
+
 =head2 daemonize
 
 Become a daemon. This will set the process as a session lead, change to '/',
@@ -916,7 +855,7 @@ Take the items from the current $ENV variable and create a formated string.
 
 =item L<XAS|XAS>
 
-=item L<Badger::Utils|http://badgerpower.com/docs/Badger/Utils.html>
+=item L<Badger::Utils|https://metacpan.org/pod/Badger::Utils>
 
 =back
 
@@ -928,10 +867,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
